@@ -6,7 +6,7 @@ use warnings;
 
 #our $VERSION = '3.002';
 
-our $VERSION = '3.001.004'; # VERSION
+our $VERSION = '3.001.005'; # VERSION
 
 use Moose;
 use Path::Tiny;
@@ -65,7 +65,7 @@ has dirs => (
         traits => ['Array'],
         handles => { skips => 'elements' },
         lazy => 1,
-        default => sub { ['lib/Bencher/ScenarioR/'] },
+        default => sub { ['^lib/Bencher/ScenarioR/', '^t/'] },
     );
 }
 
@@ -160,7 +160,7 @@ Dist::Zilla::Plugin::Test::Perl::Critic::Subset - Tests to check your code again
 
 =head1 VERSION
 
-version 3.001.004
+version 3.001.005
 
 =head1 SYNOPSIS
 
